============
Installation
============

At the command line::

    $ pip install certbot-dns-transip

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv certbot-dns-transip
    $ pip install certbot-dns-transip
